==> haskell-ptr-0.16.8.7-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-BA8DLsQKpUZ9Z8cqM22DXS
key:                  ptr-0.16.8.7-BA8DLsQKpUZ9Z8cqM22DXS
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  bbe0c11fbca5b5598d02d821c374730d
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-BA8DLsQKpUZ9Z8cqM22DXS
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.2-EsgLQtFnlIg5jr0U9yDwZT
    strict-list-0.1.7.6-LaVdCSq5ph51E6xdiDbcoJ text-2.0.2 time-1.12.2
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ptr-0.16.8.7-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ptr.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ptr
version:              0.16.8.7
visibility:           public
id:                   ptr-0.16.8.7-7t92F4KTxcn6iMITcMsyTj
key:                  ptr-0.16.8.7-7t92F4KTxcn6iMITcMsyTj
license:              MIT
copyright:            (c) 2017, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/ptr
synopsis:             Experimental abstractions for operations on pointers
description:
    Collection of experimental abstractions over pointer operations.

category:             Ptr, Data
abi:                  8440de5b422097e1baf3686dc1363dc1
exposed:              True
exposed-modules:
    Ptr.ByteString Ptr.IO Ptr.Parse Ptr.ParseUnbound Ptr.Peek Ptr.Poke
    Ptr.PokeAndPeek Ptr.Poking Ptr.Read Ptr.Receive

hidden-modules:
    Ptr.List Ptr.PokeIO Ptr.Prelude Ptr.Receive.Core
    Ptr.UncheckedShifting Ptr.Util.ByteString Ptr.Util.Word8Predicates

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ptr-0.16.8.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ptr
hs-libraries:         HSptr-0.16.8.7-7t92F4KTxcn6iMITcMsyTj
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    contravariant-1.5.5-p3peIMeiUA4Z37z2EtgYi
    profunctors-5.6.2-EsgLQtFnlIg5jr0U9yDwZT
    strict-list-0.1.7.6-3w1zuE61646EQbBQujpcSa text-2.0.2 time-1.12.2
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-ptr/html/ptr.haddock
haddock-html:         /usr/share/doc/haskell-ptr/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
